=========================
The ``lino-tera`` package
=========================



.. image:: https://readthedocs.org/projects/lino/badge/?version=latest
    :alt: Documentation Status
    :target: http://lino.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/lino-framework/tera/badge.svg?branch=master
    :target: https://coveralls.io/github/lino-framework/tera?branch=master

.. image:: https://travis-ci.org/lino-framework/tera.svg?branch=stable
    :target: https://travis-ci.org/lino-framework/tera?branch=stable

.. image:: https://img.shields.io/pypi/v/lino-tera.svg
    :target: https://pypi.python.org/pypi/lino-tera/

.. image:: https://img.shields.io/pypi/l/lino-tera.svg
    :target: https://pypi.python.org/pypi/lino-tera/

Lino Tera is a customizable management system for therapeutic centres.

- The central project homepage is http://tera.lino-framework.org

- Functional specification see
  http://www.lino-framework.org/specs/tera

- There is also a User's Manual in German: `online using Sphinx
  <http://de.tera.lino-framework.org/>`__ (work in progress) and `PDF
  using LibreOffice
  <https://github.com/lino-framework/tera/raw/master/docs/dl/Handbuch_Lino_Tera.pdf>`__
  (not maintained).

- For *introductions* and *commercial information* about Lino Tera
  please see `www.saffre-rumma.net
  <http://www.saffre-rumma.net/tera/>`__.




